@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -82,7 +82,7 @@ class SyL_ConfigFilters extends SyL_Config
      * @access private
      * @var object
      */
-    var $forward = null;
+    var $router = null;
 
     /**
      * 󥹥ȥ饯
@@ -106,7 +106,7 @@ class SyL_ConfigFilters extends SyL_Config
     function setController(&$controller)
     {
         parent::setController($controller);
-        $this->forward =& $controller->container->getComponent('forward');
+        $this->router =& $controller->container->getComponent('router');
     }
 
     /**
@@ -135,7 +135,7 @@ class SyL_ConfigFilters extends SyL_Config
 
             // ̾ǧ
             $reg = isset($attribute['path']) ? $attribute['path'] : '(.*)';
-            if (preg_match('|^(' . $reg . ')$|', $this->forward->getActionFile())) {
+            if (preg_match('|^(' . $reg . ')$|', $this->router->getActionFile())) {
                 $name = '__filter_' . $attribute['name'];
                 $this->config[$name]['class']     = $attribute['class'];
                 $this->config[$name]['type']      = 'filter';
