@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -58,7 +58,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Error.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -106,15 +106,15 @@ class SyL_ErrorWeb extends SyL_Error
             $error_trace = $this->getTraceHtml();
 
             // 顼ɽȽ
-            $forward_type = '';
+            $router_type = '';
             switch (strtolower(SYL_ERROR_FORWARD_TYPE)) {
-            case 'template': $forward_type = 'Template'; break;
-            case 'redirect': $forward_type = 'Redirect'; break;
-            default:         $forward_type = 'Default';  break;
+            case 'template': $router_type = 'Template'; break;
+            case 'redirect': $router_type = 'Redirect'; break;
+            default:         $router_type = 'Default';  break;
             }
 
             // 顼ɽ
-            $func_name = 'displayError' . $forward_type;
+            $func_name = 'displayError' . $router_type;
             call_user_func( array(&$this, $func_name), $error_type, $error_message, $error_trace);
             // 
             $this->logging($error_no, $error_message);
@@ -155,27 +155,25 @@ class SyL_ErrorWeb extends SyL_Error
     {
         // 顼å
         $error_string = "[" . $error_type . "] " . $error_message;
-        clearstatcache();
-        if (is_file(SYL_ERROR_FORWARD_FILE)) {
-            // 顼ƥץ졼Ȥ
-            // <!--ERROR_STRING-->  顼å
-            // <!--DEBUG_TRACE-->  ǥХå
-            $contents = @file_get_contents(SYL_ERROR_FORWARD_FILE);
-            if (!$contents) {
-                trigger_error( "[SyL error] error template can't get (" . SYL_ERROR_FORWARD_FILE . ")", E_USER_ERROR );
-            }
-            // ʸ֤
-            $contents = str_replace( '<!--ERROR_STRING-->', $error_string, $contents );
-            $contents = str_replace( '<!--DEBUG_TRACE-->',  $error_trace,  $contents );
-            // 顼ƥץ졼ɽ
-            echo $contents;
+        $include_file = '';
+        if (is_file(SYL_APP_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
+            $include_file = SYL_APP_DIR . '/' . SYL_ERROR_FORWARD_FILE;
+        } else if (is_file(SYL_DIR . '/' . SYL_ERROR_FORWARD_FILE)) {
+            $include_file = SYL_DIR . '/' . SYL_ERROR_FORWARD_FILE;
+        } else if (is_file(SYL_ERROR_FORWARD_FILE)) {
+            $include_file = SYL_ERROR_FORWARD_FILE;
         } else {
-            trigger_error( "[SyL error] error template not found (" . SYL_ERROR_FORWARD_FILE . ")", E_USER_ERROR );
+            trigger_error("[SyL error] error template not found (" . SYL_ERROR_FORWARD_FILE . ")", E_USER_ERROR);
         }
+
+        // 顼ƥץ졼ɤ߹
+        // $error_string
+        // $error_trace
+        include_once $include_file;
     }
 
     /**
-     * ƥץڡ˥쥯
+     * 顼ڡ˥쥯
      *
      * @access private
      * @param string 顼
