@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -158,12 +158,17 @@ echo "</pre>";
                     // եѥ
                     include_once $keys['file'];
                 } else {
-                    $this->log('info', "Component or Action or Filter include failed: file not found ({$keys['file']} or " . SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'] . ")");
+                    // ݡͥȥե뤬̵
+                    $this->log('info', "Component or Action or Filter include failed: file not found ({$keys['file']} or " . SYL_DIR . DIRECTORY_SEPARATOR . $keys['file'] . " or " . SYL_APP_DIR . DIRECTORY_SEPARATOR . $keys['file'] . ")");
                     // ٥Ⱥ
                     $this->deleteEventConfig($name, $name, $event, $keys, $tmp_config);
                     continue;
                 }
 
+                if (!class_exists($classname)) {
+                    // 饹̵
+                    trigger_error("[SyL error] Component class not found (class name: {$classname})", E_USER_ERROR);
+                }
                 if ($keys['reference']) {
                     $component =& new $classname();
                 } else {
