@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -51,16 +51,12 @@ if (SYL_CONFIG_SYSTEM_ERROR_LOG) {
 /**
  * 饤֥ǥ쥯ȥΥ󥯥롼ɥѥå
  */
-set_include_path(get_include_path() . PATH_SEPARATOR . SYL_INCLUDE_DIR);
+//set_include_path(get_include_path() . PATH_SEPARATOR . SYL_INCLUDE_DIR);
 
 /**
  * եɤ߹९饹
  */
 require_once SYL_INCLUDE_DIR . '/framework/SyL_DefinesReader.php';
-/**
- * ܾ󥯥饹
- */
-require_once SYL_INCLUDE_DIR . '/framework/SyL_Forward.php';
 /**
  * ƥʥ饹
  */
@@ -87,7 +83,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Container.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -103,14 +99,14 @@ class SyL_Controller
     /**
      * ǥ쥯ȥ롼
      *
-     * @access protected
+     * @access private
      * @var string
      */
     var $action_dir = '';
     /**
      * ƥץ졼ȥǥ쥯ȥ롼
      *
-     * @access protected
+     * @access private
      * @var string
      */
     var $template_dir = '';
@@ -124,7 +120,7 @@ class SyL_Controller
     /**
      * ƥʥ֥
      *
-     * @access protected
+     * @access private
      * @var object
      */
     var $container = null;
@@ -132,14 +128,14 @@ class SyL_Controller
      * ˴᥽å̾
      * ''ξϽ˴᥽åɤưʤ
      *
-     * @access protected
+     * @access private
      * @var string
      */
     var $destory_method = 'finalStream';
     /**
      * ˴֥
      *
-     * @access protected
+     * @access private
      * @var array
      */
     var $destory_objects = array();
@@ -148,11 +144,22 @@ class SyL_Controller
      * 󥹥ȥ饯
      *
      * @access public
+     * @param array Ķ
      */
-    function SyL_Controller()
+    function SyL_Controller($config)
     {
-        if ($this->app_name == '') {
-            trigger_error("[SyL error] App_name not exists", E_USER_ERROR);
+        // ץꥱ̾
+        if (isset($config['app_name']) && $config['app_name']) {
+            $this->app_name = $config['app_name'];
+        } else {
+            trigger_error("[SyL error] Controller parameter app_name not exists", E_USER_ERROR);
+        }
+
+        // 󥭡
+        if (isset($config['action_key']) && $config['action_key']) {
+            define('SYL_ACTION_KEY', $config['action_key']);
+        } else {
+            trigger_error("[SyL error] Controller parameter action_key not exists", E_USER_ERROR);
         }
 
         // ץꥱǥ쥯ȥ
@@ -163,13 +170,10 @@ class SyL_Controller
             register_shutdown_function(array(&$this, $this->destory_method));
         }
 
-        // 󡢥ƥץ졼ȥǥ쥯ȥ
-        if ($this->action_dir == '') {
-            $this->action_dir = SYL_APP_DIR . '/actions';
-        }
-        if ($this->template_dir == '') {
-            $this->template_dir = SYL_APP_DIR . '/templates';
-        }
+        // ǥ쥯ȥ
+        $this->action_dir = (isset($config['action_dir']) && $config['action_dir']) ? $config['action_dir'] : SYL_APP_DIR . '/actions';
+        // ƥץ졼ȥǥ쥯ȥ
+        $this->template_dir = (isset($config['template_dir']) && $config['template_dir']) ? $config['template_dir'] : SYL_APP_DIR . '/templates';
 
         // ɤ߹
         SyL_DefinesReader::readConfig($this);
