@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.3 2006/12/09 08:35:25 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loggers.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.3 2006/12/09 08:35:25 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -61,6 +61,13 @@ class SyL_Error
      * @var string
      */
     var $handler_method = 'errorHandler';
+    /**
+     * ԥ
+     * 
+     * @access public
+     * @var string
+     */
+    var $eof = "\r\n";
 
     /**
      * SyL_Error饹Υ󥹥󥹼
@@ -220,11 +227,11 @@ class SyL_Error
     function logging($error_no, $error_message)
     {
         if (class_exists('SyL_Loggers')) {
-            $log_string  = '[' . $this->getErrorType($error_no) . '] ' . $error_message . SYL_EOF;
+            $log_string  = '[' . $this->getErrorType($error_no) . '] ' . $error_message . $this->eof;
             foreach ($this->getTrace() as $value) {
                 $log_string .= "[file] "     . $value['file'] . " ";
                 $log_string .= "[line] "     . $value['line'] . " ";
-                $log_string .= "[function] " . $value['function'] . SYL_EOF;
+                $log_string .= "[function] " . $value['function'] . $this->eof;
             }
 
             // 顼٥˥¸
