@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Logger
@@ -85,7 +85,7 @@ class SyL_Logger
      * @access public
      * @var string
      */
-    var $eof = SYL_EOF;
+    var $eof = "\r\n";
 
     /**
      * 󥹥ȥ饯
